﻿using ComputerShopContracts.BindingModels;
using ComputerShopContracts.SearchModels;
using ComputerShopContracts.ViewModels;
using DocumentFormat.OpenXml.Office2010.Excel;
using Microsoft.AspNetCore.Mvc;
using OrdererClientApp.Models;
using System.ComponentModel;
using System.Diagnostics;

namespace OrdererClientApp.Controllers
{
    public class HomeController : Controller
    {
        private readonly ILogger<HomeController> _logger;

        public HomeController(ILogger<HomeController> logger)
        {
            _logger = logger;
        }

        public IActionResult Index()
        {
            if (APIClient.Client == null)
            {
                return Redirect("~/Home/Enter");
            }
            return View(APIClient.GetRequest<List<EquipmentReceivingViewModel>>($"api/equipmentreceiving/getreceivings?clientId={APIClient.Client.Id}"));
        }

		public IActionResult Order()
        {
            if (APIClient.Client == null)
            {
                return Redirect("~/Home/Enter");
            }
            return View(APIClient.GetRequest<List<OrderViewModel>>($"api/order/GetOrderList?clientId={APIClient.Client.Id}"));
        }
        public IActionResult Supply()
        {
            if (APIClient.Client == null)
            {
                return Redirect("~/Home/Enter");
            }
            return View(APIClient.GetRequest<List<SupplyViewModel>>($"api/supply/getsupplylist?clientId={APIClient.Client.Id}"));
        }

        [HttpGet]
        public IActionResult Privacy()
        {
            if (APIClient.Client == null)
            {
                return Redirect("~/Home/Enter");
            }
            return View(APIClient.Client);
        }

        [HttpPost]
        public void Privacy(string login, string password, string fio)
        {
            if (APIClient.Client == null)
            {
                throw new Exception("Вы как суда попали? Суда вход только авторизованным");
            }
            if (string.IsNullOrEmpty(login) || string.IsNullOrEmpty(password) || string.IsNullOrEmpty(fio))
            {
                throw new Exception("Введите логин, пароль и ФИО");
            }
            APIClient.PostRequest("api/client/updatedata", new ClientBindingModel
            {
                Id = APIClient.Client.Id,
                ClientFIO = fio,
                Email = login,
                Password = password
            });

            APIClient.Client.ClientFIO = fio;
            APIClient.Client.Email = login;
            APIClient.Client.Password = password;
            Response.Redirect("Index");
        }

        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }

        [HttpGet]
        public IActionResult Enter()
        {
            return View();
        }

        [HttpPost]
        public void Enter(string login, string password)
        {
            if (string.IsNullOrEmpty(login) || string.IsNullOrEmpty(password))
            {
                throw new Exception("Введите логин и пароль");
            }
            APIClient.Client = APIClient.GetRequest<ClientViewModel>($"api/client/login?login={login}&password={password}");
            if (APIClient.Client == null)
            {
                throw new Exception("Неверный логин/пароль");
            }
            Response.Redirect("Index");
        }

        [HttpGet]
        public IActionResult Register()
        {
            return View();
        }

        [HttpPost]
        public void Register(string login, string password, string fio)
        {
            if (string.IsNullOrEmpty(login) || string.IsNullOrEmpty(password) || string.IsNullOrEmpty(fio))
            {
                throw new Exception("Введите логин, пароль и ФИО");
            }
            APIClient.PostRequest("api/client/register", new ClientBindingModel
            {
                ClientFIO = fio,
                Email = login,
                Password = password
            });
            Response.Redirect("Enter");
            return;
        }

        [HttpPost]
        public void CreateReceiving()

		{
			if (APIClient.Client == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}

			APIClient.PostRequest("api/equipmentreceiving/createreceiving", new EquipmentReceivingBindingModel
			{
				ClientId = APIClient.Client.Id
			});
			Response.Redirect("Index");
        }

		[HttpPost]
		public void SetFinish(int id)
		{
			if (APIClient.Client == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}
			APIClient.PostRequest($"api/equipmentreceiving/setfinish?id={id}", id);
			Response.Redirect("Index");
		}

		[HttpPost]
		public void DeleteReceiving(int receiving)
		{
			if (APIClient.Client == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}
			APIClient.PostRequest($"api/equipmentreceiving/deletereceiving?id={receiving}", receiving);
			Response.Redirect("Index");

		}

		[HttpGet]
        public IActionResult CreateOrder()
        {
            return View();
        }
        [HttpPost]
        public void CreateOrder(int sum)
        {
            if (APIClient.Client == null)
            {
                throw new Exception("Вы как суда попали? Суда вход только авторизованным");
            }
            APIClient.PostRequest("api/order/createorder", new OrderBindingModel
            {
                ClientId = APIClient.Client.Id,
                Sum = sum
            });
            Response.Redirect("Order");
        }

        [HttpGet]
        public IActionResult DeleteOrder()
        {
            ViewBag.Components = APIClient.GetRequest<List<ComponentViewModel>>("api/main/getorderlist");
            return View();
        }
        [HttpDelete]
        public void DeleteOrder(int order)
        {
            if (APIClient.Client == null)
            {
                throw new Exception("Вы как суда попали? Суда вход только авторизованным");
            }
            APIClient.PostRequest("api/order/deleteorder", new ComponentBindingModel
            {
                Id = order
            });
            Response.Redirect("Index");
        }

		public IActionResult AddAssembly()
		{
			if (APIClient.Client == null)
			{
				return Redirect("~/Home/Enter");
			}
			ViewBag.Assemblies = APIClient.GetRequest<List<AssemblyViewModel>>($"api/assembly/getassemblylist?clientId={APIClient.Client.Id}");
			ViewBag.Orders = APIClient.GetRequest<List<OrderViewModel>>($"api/order/getorderlist?clientId={APIClient.Client.Id}");
			return View();
		}

		[HttpPost]
		public void AddAssembly(int order, int assembly, int amount)
		{
			if (APIClient.Client == null)
			{
				throw new Exception("Необходима авторизация");
			}
			APIClient.PostRequest("api/order/AddAssembly", Tuple.Create(
				new OrderSearchModel() { Id = order },
				new AssemblySearchModel() { Id = assembly },			
				amount
			));
			Response.Redirect("Order");
		}

		[HttpPost]
		public void FinishOrder(int id)
		{
			if (APIClient.Client == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}
			APIClient.PostRequest($"api/order/finishorder?id={id}", id);
			Response.Redirect("order");
		}
		[HttpPost]
		public void DeliveryOrder(int id)
		{
			if (APIClient.Client == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}
			APIClient.PostRequest($"api/order/deliveryorder?id={id}", id);
			Response.Redirect("order");
		}
		[HttpPost]
		public void TakeOrderInWork(int id)
		{
			if (APIClient.Client == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}
			APIClient.PostRequest($"api/order/takeorderinwork?id={id}", id);
			Response.Redirect("order");
		}

		[HttpPost]
        public double Calc(int count, int assembly)
        {
            var or = APIClient.GetRequest<OrderViewModel>($"api/main/getassembly?assemblyId={assembly}");
            return count * (or?.Sum ?? 1);
        }
    }
}